=== modified file 'bzrlib/tests/test_read_bundle.py'
--- bzrlib/tests/test_read_bundle.py	2006-06-20 02:32:24 +0000
+++ bzrlib/tests/test_read_bundle.py	2006-07-20 05:04:08 +0000
@@ -24,39 +24,15 @@
 import bzrlib.bzrdir
 import bzrlib.errors as errors
 from bzrlib.tests import TestCaseInTempDir
+from bzrlib.tests.test_transport import TestTransportImplementation
 import bzrlib.transport
 from bzrlib.transport.memory import MemoryTransport
 import bzrlib.urlutils
 
 
-# jam 20060615 Originally I thought I should use TestCaseWithTransport
-#       but it turns out that doesn't play well with the transport adapter
-class TestReadBundleFromURL(TestCaseInTempDir):
+class TestReadBundleFromURL(TestTransportImplementation):
     """Test that read_bundle works properly across multiple transports"""
 
-    def setUp(self):
-        super(TestReadBundleFromURL, self).setUp()
-        self._server = self.transport_server()
-        self._server.setUp()
-        self._transport = None
-
-    def tearDown(self):
-        self._transport = None
-        self._server.tearDown()
-        super(TestReadBundleFromURL, self).tearDown()
-        
-    def get_transport(self):
-        """Return a connected transport to the local directory."""
-        base_url = self._server.get_url()
-        t = bzrlib.transport.get_transport(base_url)
-        if not isinstance(t, self.transport_class):
-            # we want to make sure to construct one particular class, even if
-            # there are several available implementations of this transport;
-            # therefore construct it by hand rather than through the regular
-            # get_transport method
-            t = self.transport_class(base_url)
-        return t
-
     def get_url(self, relpath=''):
         return bzrlib.urlutils.join(self._server.get_url(), relpath)
 

=== modified file 'bzrlib/tests/test_transport.py'
--- bzrlib/tests/test_transport.py	2006-07-07 21:40:36 +0000
+++ bzrlib/tests/test_transport.py	2006-07-20 05:04:08 +0000
@@ -311,3 +311,46 @@
 class BackupTransportHandler(Transport):
     """Test transport that works as a backup for the BadTransportHandler"""
     pass
+
+
+class TestTransportImplementation(TestCaseInTempDir):
+    """Implementation verification for transports.
+    
+    To verify a transport we need a server factory, which is a callable
+    that accepts no parameters and returns an implementation of
+    bzrlib.transport.Server.
+    
+    That Server is then used to construct transport instances and test
+    the transport via loopback activity.
+
+    Currently this assumes that the Transport object is connected to the 
+    current working directory.  So that whatever is done 
+    through the transport, should show up in the working 
+    directory, and vice-versa. This is a bug, because its possible to have
+    URL schemes which provide access to something that may not be 
+    result in storage on the local disk, i.e. due to file system limits, or 
+    due to it being a database or some other non-filesystem tool.
+
+    This also tests to make sure that the functions work with both
+    generators and lists (assuming iter(list) is effectively a generator)
+    """
+    
+    def setUp(self):
+        super(TestTransportImplementation, self).setUp()
+        self._server = self.transport_server()
+        self._server.setUp()
+
+    def tearDown(self):
+        super(TestTransportImplementation, self).tearDown()
+        self._server.tearDown()
+        
+    def get_transport(self):
+        """Return a connected transport to the local directory."""
+        base_url = self._server.get_url()
+        # try getting the transport via the regular interface:
+        t = get_transport(base_url)
+        if not isinstance(t, self.transport_class): 
+            # we did not get the correct transport class type. Override the
+            # regular connection behaviour by direct construction.
+            t = self.transport_class(base_url)
+        return t

=== modified file 'bzrlib/tests/test_transport_implementations.py'
--- bzrlib/tests/test_transport_implementations.py	2006-07-14 19:25:24 +0000
+++ bzrlib/tests/test_transport_implementations.py	2006-07-20 05:04:08 +0000
@@ -31,6 +31,7 @@
                            InvalidURL)
 from bzrlib.osutils import getcwd
 from bzrlib.tests import TestCaseInTempDir, TestSkipped
+from bzrlib.tests.test_transport import TestTransportImplementation
 from bzrlib.transport import memory
 import bzrlib.transport
 import bzrlib.urlutils as urlutils
@@ -45,53 +46,12 @@
         f.close()
 
 
-class TestTransportImplementation(TestCaseInTempDir):
-    """Implementation verification for transports.
-    
-    To verify a transport we need a server factory, which is a callable
-    that accepts no parameters and returns an implementation of
-    bzrlib.transport.Server.
-    
-    That Server is then used to construct transport instances and test
-    the transport via loopback activity.
-
-    Currently this assumes that the Transport object is connected to the 
-    current working directory.  So that whatever is done 
-    through the transport, should show up in the working 
-    directory, and vice-versa. This is a bug, because its possible to have
-    URL schemes which provide access to something that may not be 
-    result in storage on the local disk, i.e. due to file system limits, or 
-    due to it being a database or some other non-filesystem tool.
-
-    This also tests to make sure that the functions work with both
-    generators and lists (assuming iter(list) is effectively a generator)
-    """
-    
-    def setUp(self):
-        super(TestTransportImplementation, self).setUp()
-        self._server = self.transport_server()
-        self._server.setUp()
-
-    def tearDown(self):
-        super(TestTransportImplementation, self).tearDown()
-        self._server.tearDown()
-        
+class TransportTests(TestTransportImplementation):
+
     def check_transport_contents(self, content, transport, relpath):
         """Check that transport.get(relpath).read() == content."""
         self.assertEqualDiff(content, transport.get(relpath).read())
 
-    def get_transport(self):
-        """Return a connected transport to the local directory."""
-        base_url = self._server.get_url()
-        t = bzrlib.transport.get_transport(base_url)
-        if not isinstance(t, self.transport_class):
-            # we want to make sure to construct one particular class, even if
-            # there are several available implementations of this transport;
-            # therefore construct it by hand rather than through the regular
-            # get_transport method
-            t = self.transport_class(base_url)
-        return t
-
     def assertListRaises(self, excClass, func, *args, **kwargs):
         """Fail unless excClass is raised when the iterator from func is used.
         

